@@ -100,14 +100,14 @@ y <- matrix(y,ntags,nlibs)
 colnames(y) <- c("x0","x1","x2")
 rownames(y) <- paste("Gene",1:ntags,sep="")
 d <- DGEList(y)
-d <- calcNormFactors(d,method="TMM")
+d <- normLibSizes(d,method="TMM")
 fit <- glmFit(d, design, dispersion=dispersion.true, prior.count=0.5/3)
 results <- glmLRT(fit, coef=2)
 topTags(results)
 d1 <- estimateGLMCommonDisp(d, design, verbose=TRUE)
 glmFit(d,design,dispersion=dispersion.true, prior.count=0.5/3)
 
-calcNormFactors(d$counts,method="TMMwsp")
+normLibSizes(d$counts,method="TMMwsp")
 
 d2 <- estimateDisp(d, design)
 summary(d2$tagwise.dispersion)
@@ -174,7 +174,7 @@ y$tagwise.dispersion[1:10]
 summary(y$tagwise.dispersion)
 
 # glmQLFit
-fit <- glmQLFit(y,design) # legacy=TRUE
+fit <- glmQLFit(y,design,legacy=FALSE)
 fit$dispersion
 summary(fit$var.post)
 fit$unit.deviance.adj[1:10,]
